import { describe, expect, it, beforeEach, vi } from 'vitest';
import { MagicLinkService } from '../../services/magiclink.service.js';
describe('MagicLinkService', () => {
    let service;
    const baseUrl = 'http://test.com';
    const tokenExpiry = 300000; // 5 minutes
    const jwtSecret = 'test-secret';
    beforeEach(() => {
        service = new MagicLinkService({
            baseUrl,
            tokenExpiry,
            jwtSecret
        });
        vi.useFakeTimers();
    });
    afterEach(() => {
        vi.useRealTimers();
    });
    describe('createMagicLink', () => {
        it('should create a valid magic link token', async () => {
            const npub = 'npub1xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';
            const token = await service.createMagicLink(npub);
            expect(token).toBeDefined();
            expect(typeof token).toBe('string');
            expect(service.sessions.size).toBe(1);
        });
        it('should throw error with invalid pubkey', async () => {
            const invalidPubkey = 'invalid-pubkey';
            await expect(service.createMagicLink(invalidPubkey)).rejects.toThrow();
        });
        it('should create token with custom expiry', async () => {
            const npub = 'npub1xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';
            const customExpiry = 600000; // 10 minutes
            service = new MagicLinkService({
                baseUrl,
                tokenExpiry: customExpiry,
                jwtSecret
            });
            const token = await service.createMagicLink(npub);
            expect(token).toBeDefined();
        });
    });
    describe('verifyMagicLink', () => {
        it('should verify a valid token', async () => {
            const npub = 'npub1xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';
            const token = await service.createMagicLink(npub);
            const result = await service.verifyMagicLink(token);
            expect(result).toBe(npub);
        });
        it('should return null for an invalid token', async () => {
            const result = await service.verifyMagicLink('invalid-token');
            expect(result).toBeNull();
        });
        it('should return null for an expired token', async () => {
            const npub = 'npub1xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';
            const token = await service.createMagicLink(npub);
            // Fast forward past expiry
            vi.advanceTimersByTime(tokenExpiry + 1000);
            const result = await service.verifyMagicLink(token);
            expect(result).toBeNull();
        });
        it('should handle malformed tokens', async () => {
            const result = await service.verifyMagicLink('malformed.token.here');
            expect(result).toBeNull();
        });
        it('should handle tokens signed with different secret', async () => {
            const npub = 'npub1xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';
            const token = await service.createMagicLink(npub);
            // Create new service with different secret
            const newService = new MagicLinkService({
                baseUrl,
                tokenExpiry,
                jwtSecret: 'different-secret'
            });
            const result = await newService.verifyMagicLink(token);
            expect(result).toBeNull();
        });
    });
});
