import { describe, expect, it, beforeEach, vi } from 'vitest';
import { NostrService } from '../../services/nostr.service.js';
import { SimplePool } from 'nostr-tools';
// Mock nostr-tools
vi.mock('nostr-tools', () => ({
    SimplePool: vi.fn().mockImplementation(() => ({
        ensureRelay: vi.fn().mockResolvedValue({}),
        publish: vi.fn().mockResolvedValue(true),
        sub: vi.fn().mockReturnValue({
            on: vi.fn(),
            unsub: vi.fn()
        }),
        close: vi.fn()
    })),
    nip04: {
        encrypt: vi.fn().mockResolvedValue('encrypted-content'),
        decrypt: vi.fn().mockResolvedValue('decrypted-message')
    },
    nip19: {
        decode: vi.fn().mockReturnValue({ data: 'decoded-pubkey' }),
        npubEncode: vi.fn().mockReturnValue('npub1...'),
    },
    getPublicKey: vi.fn().mockReturnValue('test-pubkey'),
    getEventHash: vi.fn().mockReturnValue('test-hash'),
    signEvent: vi.fn().mockReturnValue('test-signature'),
}));
describe('NostrService', () => {
    let service;
    const privateKey = '0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef'; // 64-char hex
    const relays = ['wss://test.relay'];
    beforeEach(() => {
        vi.clearAllMocks();
        service = new NostrService({
            privateKey,
            relays
        });
    });
    afterEach(() => {
        vi.clearAllMocks();
    });
    it('should initialize with valid keys', () => {
        expect(service).toBeDefined();
        expect(service.pool).toBeDefined();
    });
    it('should connect to relays', async () => {
        await service.connect();
        expect(service.pool).toBeDefined();
        // SimplePool is created and ensureRelay is called for each relay
        expect(SimplePool).toHaveBeenCalled();
    });
    it('should send DM', async () => {
        const recipientPubkey = 'recipient-pubkey';
        const message = 'test message';
        await service.connect();
        await service.sendDM(recipientPubkey, message);
        // Verify encryption and publishing
        expect(service.pool.publish).toHaveBeenCalled();
    });
    it('should receive DM', async () => {
        const senderPubkey = 'sender-pubkey';
        const mockEvent = {
            pubkey: senderPubkey,
            created_at: Math.floor(Date.now() / 1000),
            kind: 4,
            tags: [],
            content: 'encrypted-content',
            id: 'test-id',
            sig: 'test-sig'
        };
        // Mock sub to emit the event
        const mockSub = {
            on: vi.fn().mockImplementation((event, callback) => {
                if (event === 'event') {
                    callback(mockEvent);
                }
            }),
            unsub: vi.fn()
        };
        service.pool.sub = vi.fn().mockReturnValue(mockSub);
        await service.connect();
        const message = await service.receiveDM(senderPubkey);
        expect(message).toBe('decrypted-message');
    });
    it('should format pubkey correctly', () => {
        const npub = 'npub1xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';
        service.formatPubkey(npub);
        expect(service.pool).toBeDefined();
    });
    it('should verify DM successfully', async () => {
        const event = {
            id: 'test-id',
            pubkey: 'test-pubkey',
            created_at: Math.floor(Date.now() / 1000),
            kind: 4,
            tags: [],
            content: 'encrypted-content',
            sig: 'test-sig'
        };
        const result = await service.verifyDM(event);
        expect(result).toBe('decrypted-message');
    });
    it('should disconnect and cleanup', async () => {
        await service.connect();
        await service.disconnect();
        service.cleanup();
        expect(service.pool.close).toHaveBeenCalled();
    });
});
