import { getPublicKey, signEvent } from 'nostr-crypto-utils';
import { NostrError } from '../types/errors';
/**
 * Creates a NIP-02 contact list event
 * @param privateKey - The private key to sign the event with
 * @param contacts - Array of contacts to include in the list
 * @returns A signed contact list event
 */
export async function createContactList(privateKey, contacts) {
    const pubkey = await getPublicKey(privateKey);
    // Create unsigned event first
    const unsignedEvent = {
        kind: 3,
        pubkey,
        created_at: Math.floor(Date.now() / 1000),
        tags: contacts.map(contact => {
            const tag = ['p', contact.pubkey];
            if (contact.relay)
                tag.push(contact.relay);
            if (contact.petname)
                tag.push(contact.petname);
            return tag;
        }),
        content: '',
        id: '', // Will be set by signEvent
        sig: '', // Will be set by signEvent
    };
    // Sign the event which will set id and sig
    return await signEvent(unsignedEvent, privateKey);
}
/**
 * Parses a NIP-02 contact list event
 * @param event - The contact list event to parse
 * @returns Array of parsed contacts
 */
export function parseContactList(event) {
    if (event.kind !== 3) {
        throw new NostrError('Invalid event kind. Expected kind 3 for contact list.');
    }
    return event.tags
        .filter(tag => {
        // Strictly validate tag format according to NIP-02
        return Array.isArray(tag) &&
            tag[0] === 'p' &&
            tag.length >= 2 &&
            typeof tag[1] === 'string';
    })
        .map(tag => ({
        pubkey: tag[1],
        ...(tag[2] && typeof tag[2] === 'string' && { relay: tag[2] }),
        ...(tag[3] && typeof tag[3] === 'string' && { petname: tag[3] })
    }));
}
