/**
 * @module protocol/messages
 * @description Message handling for Nostr protocol
 */
import { encryptMessage } from 'nostr-crypto-utils';
import { logger } from '../utils/logger';
import { NostrError, NostrErrorCode } from '../types/nostr';
/**
 * Manages message encryption and verification for Nostr protocol
 * Provides utilities for secure message handling between users
 */
export class MessageManager {
    /**
     * Encrypt a message for a recipient
     * @param content Message content to encrypt
     * @param recipientPubkey Recipient's public key
     * @param senderPrivateKey Sender's private key
     * @returns Encrypted message content
     * @throws {NostrError} If encryption fails
     */
    async encryptMessage(content, recipientPubkey, senderPrivateKey) {
        try {
            return await encryptMessage(content, recipientPubkey, senderPrivateKey);
        }
        catch (error) {
            throw new NostrError('Failed to encrypt message', NostrErrorCode.ENCRYPTION_FAILED, { cause: error });
        }
    }
    /**
     * Verify a received message
     * @param senderPubkey Sender's public key
     * @returns True if message is verified
     * @throws {NostrError} If verification fails
     */
    async verifyMessage(senderPubkey) {
        try {
            // Implementation for message verification
            logger.info('Message verified from:', senderPubkey);
            return true;
        }
        catch (error) {
            throw new NostrError('Failed to verify message', NostrErrorCode.VERIFICATION_FAILED, { cause: error });
        }
    }
}
