import { nip19 } from 'nostr-tools';
import { createEvent } from './nip01';
import { NostrError, NostrErrorCode } from '../../types/nostr';
import { logger } from '../../utils/logger';
/**
 * Formats a public key into its npub format according to NIP-02
 * @param pubkey - The public key to format, can be in hex or npub format
 * @returns The public key in npub format
 * @throws {Error} If the public key format is invalid
 */
export function formatPublicKey(pubkey) {
    try {
        // If it's already an npub, validate it
        if (pubkey.startsWith('npub1')) {
            const { type } = nip19.decode(pubkey);
            if (type !== 'npub') {
                throw new Error('Invalid npub format');
            }
            return pubkey;
        }
        // Convert hex to npub
        return nip19.npubEncode(pubkey);
    }
    catch (error) {
        throw new Error('Invalid public key format');
    }
}
/**
 * Validates a public key format according to NIP-02
 * @param pubkey - The public key to validate, can be in hex or npub format
 * @returns True if the public key format is valid, false otherwise
 */
export function validatePublicKey(pubkey) {
    try {
        if (pubkey.startsWith('npub1')) {
            const { type } = nip19.decode(pubkey);
            return type === 'npub';
        }
        // Validate hex format
        return /^[0-9a-f]{64}$/.test(pubkey.toLowerCase());
    }
    catch {
        return false;
    }
}
/**
 * Create a contact list event (NIP-02)
 * @param contacts - List of contacts to include
 * @param privateKey - Private key to sign the event
 * @returns Signed contact list event
 * @throws {NostrError} If event creation fails
 */
export const createContactList = (contacts, privateKey) => {
    try {
        // Convert contacts to tags format
        const tags = contacts.map(contact => {
            const tag = ['p', contact.pubkey, contact.relay];
            if (contact.petname) {
                tag.push(contact.petname);
            }
            return tag;
        });
        // Create the event with kind 3 (contact list)
        return createEvent('', 3, privateKey, tags);
    }
    catch (error) {
        logger.error('Failed to create contact list', { error });
        throw new NostrError('Failed to create contact list', NostrErrorCode.EVENT_CREATION_ERROR, { cause: error });
    }
};
/**
 * Parse a contact list event
 * @param event - Contact list event to parse
 * @returns List of contacts
 * @throws {NostrError} If parsing fails or event kind is invalid
 */
export const parseContactList = (event) => {
    try {
        if (event.kind !== 3) {
            throw new NostrError('Invalid event kind for contact list', NostrErrorCode.INVALID_EVENT);
        }
        return event.tags
            .filter(tag => tag[0] === 'p' && tag.length >= 3)
            .map(tag => ({
            pubkey: tag[1],
            relay: tag[2],
            petname: tag[3]
        }));
    }
    catch (error) {
        logger.error('Failed to parse contact list', { error });
        throw new NostrError('Failed to parse contact list', NostrErrorCode.PARSING_ERROR, { cause: error });
    }
};
