"use strict";
/**
 * @module protocol/relay
 * @description Nostr relay connection handling and management
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RelayManager = void 0;
const ws_1 = require("ws");
const logger_1 = require("../utils/logger");
const environment_1 = require("../config/environment");
const nostr_1 = require("../types/nostr");
class RelayManager {
    constructor(relayUrl) {
        this.ws = null;
        this.retryCount = 0;
        this.relay = {
            url: relayUrl,
            status: 'disconnected'
        };
    }
    async connect() {
        if (this.ws?.readyState === ws_1.WebSocket.OPEN) {
            return;
        }
        try {
            this.ws = new ws_1.WebSocket(this.relay.url);
            this.relay.status = 'connecting';
            await new Promise((resolve, reject) => {
                if (!this.ws)
                    return reject(new Error('WebSocket not initialized'));
                this.ws.on('open', () => {
                    this.relay.status = 'connected';
                    this.lastConnected = new Date();
                    this.retryCount = 0;
                    logger_1.logger.info('Connected to relay:', this.relay.url);
                    resolve();
                });
                this.ws.on('error', (error) => {
                    this.relay.status = 'error';
                    this.lastError = error;
                    reject(error);
                });
            });
        }
        catch (error) {
            this.relay.status = 'error';
            this.lastError = error;
            if (this.retryCount < (0, environment_1.getConfig)().retryAttempts) {
                this.retryCount++;
                logger_1.logger.warn(`Connection failed, attempt ${this.retryCount} of ${(0, environment_1.getConfig)().retryAttempts}`);
                await new Promise(resolve => setTimeout(resolve, (0, environment_1.getConfig)().retryDelay));
                return this.connect();
            }
            throw new nostr_1.NostrError('Failed to connect to relay', nostr_1.NostrErrorCode.RELAY_CONNECTION_FAILED, error);
        }
    }
    disconnect() {
        if (this.ws) {
            this.ws.close();
        }
        this.relay.status = 'disconnected';
        logger_1.logger.info('Disconnected from relay:', this.relay.url);
    }
    getStatus() {
        return this.relay;
    }
}
exports.RelayManager = RelayManager;
