/**
 * @module logger
 * @description Logger utility for the application
 */
import pino from 'pino';
/**
 * Redacts sensitive data from objects before logging
 * @param obj - Object to redact
 * @returns Redacted object
 */
function redactSensitiveData(obj) {
    if (!obj || typeof obj !== 'object')
        return obj;
    const sensitiveFields = ['privkey', 'nsec', 'secret', 'password', 'token'];
    const redactedObj = { ...obj };
    for (const key in redactedObj) {
        if (sensitiveFields.some(field => key.toLowerCase().includes(field))) {
            redactedObj[key] = '[REDACTED]';
        }
        else if (typeof redactedObj[key] === 'object') {
            redactedObj[key] = redactSensitiveData(redactedObj[key]);
        }
    }
    return redactedObj;
}
/**
 * Create a logger instance with consistent configuration
 * @param name - Component or module name for the logger
 * @returns Configured pino logger instance
 */
export function createLogger(name) {
    return pino({
        name,
        level: process.env.LOG_LEVEL || 'info',
        transport: process.env.NODE_ENV === 'development' ? {
            target: 'pino-pretty',
            options: {
                colorize: true,
                translateTime: 'HH:MM:ss',
                ignore: 'pid,hostname',
            }
        } : undefined,
        formatters: {
            level: (label) => {
                return { level: label.toUpperCase() };
            },
            log: (obj) => {
                // Redact sensitive data
                return redactSensitiveData(obj);
            }
        },
        mixin: () => ({})
    });
}
/**
 * Simple log function for basic logging needs
 * @param message - Message to log
 * @param data - Optional data to include
 */
export function log(message, data) {
    const redactedData = data ? redactSensitiveData(data) : undefined;
    console.log(message, redactedData);
}
/**
 * Default logger instance for the application
 * Includes enhanced error handling and formatting
 */
export const logger = createLogger('nostr-dm-magiclink-utils');
